
#line 3 "lex.grib_yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define grib_yyconst const
#else
#define grib_yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (grib_yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((grib_yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE grib_yyrestart(grib_yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(grib_yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct grib_yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int grib_yyleng;

extern FILE *grib_yyin, *grib_yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define grib_yyless(n) \
	do \
		{ \
		/* Undo effects of setting up grib_yytext. */ \
        int grib_yyless_macro_arg = (n); \
        YY_LESS_LINENO(grib_yyless_macro_arg);\
		*grib_yy_cp = (grib_yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(grib_yy_c_buf_p) = grib_yy_cp = grib_yy_bp + grib_yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up grib_yytext again */ \
		} \
	while ( 0 )

#define unput(c) grib_yyunput( c, (grib_yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t grib_yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct grib_yy_buffer_state
	{
	FILE *grib_yy_input_file;

	char *grib_yy_ch_buf;		/* input buffer */
	char *grib_yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	grib_yy_size_t grib_yy_buf_size;

	/* Number of characters read into grib_yy_ch_buf, not including EOB
	 * characters.
	 */
	int grib_yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int grib_yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int grib_yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int grib_yy_at_bol;

    int grib_yy_bs_lineno; /**< The line count. */
    int grib_yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int grib_yy_fill_buffer;

	int grib_yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via grib_yyrestart()), so that the user can continue scanning by
	 * just pointing grib_yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t grib_yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t grib_yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * grib_yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (grib_yy_buffer_stack) \
                          ? (grib_yy_buffer_stack)[(grib_yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (grib_yy_buffer_stack)[(grib_yy_buffer_stack_top)]

/* grib_yy_hold_char holds the character lost when grib_yytext is formed. */
static char grib_yy_hold_char;
static int grib_yy_n_chars;		/* number of characters read into grib_yy_ch_buf */
int grib_yyleng;

/* Points to current character in buffer. */
static char *grib_yy_c_buf_p = (char *) 0;
static int grib_yy_init = 0;		/* whether we need to initialize */
static int grib_yy_start = 0;	/* start state number */

/* Flag which is used to allow grib_yywrap()'s to do buffer switches
 * instead of setting up a fresh grib_yyin.  A bit of a hack ...
 */
static int grib_yy_did_buffer_switch_on_eof;

void grib_yyrestart (FILE *input_file  );
void grib_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE grib_yy_create_buffer (FILE *file,int size  );
void grib_yy_delete_buffer (YY_BUFFER_STATE b  );
void grib_yy_flush_buffer (YY_BUFFER_STATE b  );
void grib_yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void grib_yypop_buffer_state (void );

static void grib_yyensure_buffer_stack (void );
static void grib_yy_load_buffer_state (void );
static void grib_yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER grib_yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE grib_yy_scan_buffer (char *base,grib_yy_size_t size  );
YY_BUFFER_STATE grib_yy_scan_string (grib_yyconst char *grib_yy_str  );
YY_BUFFER_STATE grib_yy_scan_bytes (grib_yyconst char *bytes,int len  );

void *grib_yyalloc (grib_yy_size_t  );
void *grib_yyrealloc (void *,grib_yy_size_t  );
void grib_yyfree (void *  );

#define grib_yy_new_buffer grib_yy_create_buffer

#define grib_yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        grib_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grib_yy_create_buffer(grib_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grib_yy_is_interactive = is_interactive; \
	}

#define grib_yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        grib_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grib_yy_create_buffer(grib_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grib_yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->grib_yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *grib_yyin = (FILE *) 0, *grib_yyout = (FILE *) 0;

typedef int grib_yy_state_type;

extern int grib_yylineno;

int grib_yylineno = 1;

extern char *grib_yytext;
#define grib_yytext_ptr grib_yytext

static grib_yy_state_type grib_yy_get_previous_state (void );
static grib_yy_state_type grib_yy_try_NUL_trans (grib_yy_state_type current_state  );
static int grib_yy_get_next_buffer (void );
static void grib_yy_fatal_error (grib_yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up grib_yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(grib_yytext_ptr) = grib_yy_bp; \
	grib_yyleng = (size_t) (grib_yy_cp - grib_yy_bp); \
	(grib_yy_hold_char) = *grib_yy_cp; \
	*grib_yy_cp = '\0'; \
	(grib_yy_c_buf_p) = grib_yy_cp;

#define YY_NUM_RULES 121
#define YY_END_OF_BUFFER 122
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct grib_yy_trans_info
	{
	flex_int32_t grib_yy_verify;
	flex_int32_t grib_yy_nxt;
	};
static grib_yyconst flex_int16_t grib_yy_accept[634] =
    {   0,
      118,  118,  122,  120,  118,  119,   12,  109,  117,  120,
      120,  120,  112,    5,  120,    3,  111,  111,  111,  110,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      120,   18,  118,    6,   14,  113,  115,    0,  114,  112,
        0,    4,    7,    1,    2,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,   20,  111,   10,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,   15,  111,  111,  111,

      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,   16,    0,  116,  114,    0,    0,  116,
      111,   21,  111,   13,  111,  111,  111,    8,  111,   58,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,   32,  111,  111,  111,  111,  111,  111,  111,
      111,   82,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,   11,  111,  111,   45,  111,
      111,  111,  111,  111,   96,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,    0,  115,
        0,    0,  114,  111,  111,  111,  111,  111,   95,   25,

      111,   99,  111,  111,  111,  111,  111,  111,  111,   73,
      111,   22,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,   59,  111,  111,   27,
      111,  111,  111,  111,   41,  111,  111,  111,  111,  111,
       17,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      107,  111,  111,  111,  111,  111,  111,  111,  111,   98,
      111,  111,    0,  114,  111,   48,  111,   24,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
       39,  111,  111,  111,  111,  111,  111,  111,  111,   84,
       88,   92,  111,  111,   26,  111,  111,  111,  111,  111,

      111,  111,  111,  111,  111,  111,   43,  111,  106,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,   81,  111,  111,   28,  104,  111,  105,   69,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
       66,  111,  111,  111,  111,   37,   75,  111,  111,  111,
      111,  111,  111,  111,  111,   68,  111,   40,  111,  111,
       62,  111,  111,  111,    9,  111,  111,  111,  111,  111,
       67,  111,  111,   35,  111,  100,  111,  111,  111,   83,
       87,   91,  111,  111,   77,  111,  111,  111,  102,  111,
      111,   80,  101,  111,  111,   60,  111,  111,  111,  111,

      111,  108,  111,  111,  111,  111,  111,  111,  111,   47,
       57,   71,   74,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,   31,  111,  111,  111,   49,  111,  111,
      111,  111,  111,   51,  111,  111,  111,  111,  111,  111,
       33,  111,  111,  111,  111,   56,  111,  111,  111,   79,
      111,  111,   50,  111,  111,  111,  111,   29,  111,  111,
      111,  111,   23,  111,   36,  111,  111,  111,  111,  111,
      111,  111,  111,   34,  111,  111,  111,  111,   54,   19,
       42,  111,   70,  111,  111,  111,  111,   52,  111,  111,
      111,  111,  111,  111,   78,  111,  111,  111,  111,  111,

      111,  111,  111,  111,  111,  111,   97,  111,  111,  111,
      111,  111,  111,  111,  111,   55,  111,  111,  111,  111,
      111,  111,  111,   61,  111,  111,   53,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,   44,  111,  111,
      111,  111,  111,   76,  111,  103,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,   46,   30,  111,  111,
      111,  111,   72,  111,  111,  111,  111,  111,  111,  111,

      111,  111,   38,  111,   64,  111,  111,  111,  111,  111,
      111,  111,  111,   65,  111,  111,  111,  111,  111,  111,
      111,   86,   90,   94,  111,  111,  111,  111,   85,   89,
       93,   63,    0
    } ;

static grib_yyconst flex_int32_t grib_yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    1,    1,    7,    8,    1,
        1,    1,    9,    1,    9,   10,    1,   11,   12,   13,
       14,   15,   11,   16,   11,   17,   11,    1,    1,   18,
       19,   20,    1,    1,   21,   21,   21,   21,   22,   21,
       23,   21,   24,   21,   21,   21,   25,   26,   21,   21,
       21,   21,   27,   21,   21,   21,   21,   21,   21,   21,
        1,    1,    1,    1,   28,   29,   30,   31,   32,   33,

       34,   35,   36,   37,   38,   21,   39,   40,   41,   42,
       43,   44,   21,   45,   46,   47,   48,   49,   50,   51,
       52,   21,    1,   53,    1,   54,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static grib_yyconst flex_int32_t grib_yy_meta[55] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    2,
        3,    3,    3,    3,    3,    3,    3,    1,    1,    1,
        4,    3,    4,    4,    4,    4,    4,    4,    1,    4,
        4,    4,    4,    3,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    1,    1
    } ;

static grib_yyconst flex_int16_t grib_yy_base[641] =
    {   0,
        0,    0, 1211, 1212, 1208, 1212, 1190, 1212, 1212, 1201,
       44,   51,   60,   52, 1188, 1187,   62,   72,   57, 1212,
       66,   73,   74,   75,   91,   67,   68,   76,  103,   95,
      105,  112,  120,   77,  127,   69,  128,  135,  123,  134,
     1152, 1212, 1202, 1212, 1212,  164,   98,  176,  106,  172,
      188, 1212, 1212, 1212, 1212,    0, 1179,  129,  160,  172,
       97,  183,  184,  136,  185,  161,  187,  189,  196,  190,
      191,  195,  194,  197,  193,  198,  217, 1174,  199,  200,
      220,  221, 1177,  224, 1176,  225,  226,  227,  228,  229,
      230,  238,  233,  239,  240,  241, 1175,  243,  250,  252,

      254,  258,  262,  140,  255,  265,  266,  267,  273,  271,
      272,  281,  276, 1212,  311,  307,  299,  323,  331,  338,
      332, 1174,  277, 1173,  333,  334,  336, 1172,  337, 1171,
      339,  338,  340,  341,  345,  347,  352,  282,  353,  354,
      356,  357, 1170,  358,  359,  351,  362,  361,  375,  366,
      378,  393,  363,  382,  387,  388,  389,  391,  392,  395,
      396,  398,  399,  401,  406,  402,  408,  410,  411,  415,
      419,  416,  420,  421,  423,  428,  430,  426,  432,  433,
      436,  435,  438,  441,  442,  445,  443,  448,  477,  485,
      494,  501,  508, 1169,  458,  502,  503,  504, 1168, 1167,

      505, 1166,  506,  507,  452,  508,  509,  510,  511, 1165,
      514, 1164,  515,  519, 1157, 1152, 1151,  521,  522,  524,
      449,  518, 1168, 1170, 1167,  537,  545,  530,  535, 1157,
      544,  538,  547,  549, 1156,  550,  553,  551,  554,  552,
     1155,  556,  557,  559,  564,  565,  567,  571,  572,  573,
     1154,  575,  578,  579,  574,  588,  609,  580,  591, 1153,
      598,  604,  628,  635,  605, 1152,  629, 1151,  589,  630,
      631,  632,  613,  635,  634,  636,  639,  643,  644,  645,
     1150, 1133, 1126, 1139,  581,  646,  647,  654,  648, 1142,
     1141, 1140,  650, 1133, 1142,  655,  651,  658,  661,  660,

      663,  665,  675,  671,  676,  679,  680,  682, 1141,  681,
      684,  683,  686,  689,  692,  688,  703,  706,  707, 1148,
     1150, 1147,    0,  708,  710, 1137, 1136,  307, 1135, 1134,
      711,  712,  584,  713,  716,  718,  722,  721,  723,  725,
     1133,  726, 1121, 1109, 1107, 1129, 1128,  729,  731,  730,
     1111, 1110, 1109,  732, 1097, 1123,  733, 1122,  739,  738,
     1121,  741,  742,  746, 1120,  747,  752,  754,  753,  755,
     1119,  757,  758, 1118,  759, 1117,  760,  766,  765, 1112,
     1111, 1110,  767,  771, 1113,  768,  774,  780,  787,  779,
      782, 1112, 1111,  788,  793, 1110, 1105, 1102, 1093,  792,

      794, 1106, 1091, 1090, 1089,  795, 1082,  798,  799, 1101,
     1100, 1099, 1098,  803,  804,  801,  805,  806,  808,  819,
      807,  810,  809, 1097, 1080, 1079, 1078, 1093,  824,  826,
      828,  829,  831, 1092,  832,  834,  835, 1084, 1078, 1070,
     1088,  836, 1064, 1063, 1062, 1084, 1058,  841,  842, 1082,
      843,  844, 1081,  845,  846,  839,  847,  854,  848, 1066,
     1065, 1064, 1077,  855, 1076,  860,  863,  864,  856,  865,
     1047, 1064, 1055, 1072, 1048, 1047, 1046, 1058, 1067, 1066,
     1065,  869, 1064,  868,  870,  872,  878, 1063, 1039, 1038,
     1037,  880,  881,  884, 1059,  888,  889, 1035, 1053, 1065,

     1039, 1038, 1037, 1031,  891,  894, 1051,  897,  893, 1027,
     1026, 1025,  900,  905,  904, 1047,  901, 1036, 1029, 1040,
     1033, 1032, 1031,    0,  906,  908, 1040,  913, 1023, 1022,
     1021,  916,  918,  919,  921, 1032, 1025, 1018, 1029, 1028,
     1027,  920,  923,  925, 1020, 1019, 1018,  926,  936,  927,
      928, 1019, 1008, 1015, 1014, 1013, 1012, 1021,  929,  932,
     1016, 1015, 1014, 1017,  944, 1016,  940,  996, 1002,  995,
      994,  993,  992,  945,  948,  999,  998,  997,  949,  950,
      997,  982,  992,  994,  993,  992, 1000,  999,  980,  979,
      978,  952,  995,  984,  980,  969,  977,  976,  975,  979,

      978,  977,  985,  973,    0,  970,  976,  975,  974,  965,
      964,  963,  960,    0,  945,  943,  942,  953,  950,  949,
      947,    0,    0,    0,  659,  592,  498,  439,    0,    0,
        0,    0, 1212,  988,  989,  992,  174,  102,  993,  996
    } ;

static grib_yyconst flex_int16_t grib_yy_def[641] =
    {   0,
      633,    1,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  634,  633,  633,  633,  635,  635,   18,  633,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
      633,  633,  633,  633,  633,  636,  637,  633,  638,  634,
      633,  633,  633,  633,  633,  639,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,  639,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,

       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,  633,  633,  640,  638,  633,  633,  633,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,  639,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,  633,  633,
      633,  633,  633,   18,   18,   18,   18,   18,   18,   18,

       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,  639,  639,  639,   18,   18,   18,
       18,   18,  639,  639,  639,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,  633,  633,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,  639,  639,  639,   18,   18,   18,   18,   18,  639,
      639,  639,   18,  639,   18,   18,   18,   18,   18,   18,

       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,  639,
      639,  639,  639,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,  639,  639,  639,   18,   18,   18,   18,   18,
      639,  639,  639,   18,  639,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,  639,
      639,  639,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,  639,  639,  639,   18,

       18,   18,  639,  639,  639,   18,  639,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,  639,  639,  639,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,  639,  639,  639,
       18,   18,  639,  639,  639,   18,  639,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,  639,
      639,  639,   18,   18,   18,   18,   18,   18,   18,   18,
      639,  639,  639,   18,  639,  639,  639,  639,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,  639,  639,
      639,   18,   18,   18,   18,   18,   18,  639,  639,  639,

      639,  639,  639,  639,   18,   18,   18,   18,   18,  639,
      639,  639,   18,   18,   18,   18,   18,  639,  639,  639,
      639,  639,  639,  639,   18,   18,   18,   18,  639,  639,
      639,   18,   18,   18,   18,  639,  639,  639,  639,  639,
      639,   18,   18,   18,  639,  639,  639,   18,   18,   18,
       18,  639,  639,  639,  639,  639,  639,   18,   18,   18,
      639,  639,  639,   18,   18,   18,   18,  639,  639,  639,
      639,  639,  639,   18,   18,  639,  639,  639,   18,   18,
      639,  639,  639,  639,  639,  639,   18,   18,  639,  639,
      639,   18,   18,  639,  639,  639,  639,  639,  639,  639,

      639,  639,   18,  639,  639,  639,  639,  639,  639,  639,
      639,  639,  639,  639,  639,  639,  639,  639,  639,  639,
      639,  639,  639,  639,  639,  639,  639,  639,  639,  639,
      639,  639,    0,  633,  633,  633,  633,  633,  633,  633
    } ;

static grib_yyconst flex_int16_t grib_yy_nxt[1267] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,    8,   11,   12,
       13,   13,   13,   13,   13,   13,   13,   14,   15,   16,
       17,   17,   17,   17,   18,   17,   17,   19,   20,   21,
       22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   36,   37,   38,   39,   17,   40,
       17,   17,   41,   42,   46,   46,   46,   46,   46,   46,
       46,   47,   47,   47,   47,   47,   47,   47,   48,   49,
       52,   53,   56,   56,   56,   56,   56,   56,   56,   78,
       57,   51,   56,   56,   56,   56,   56,   56,   56,   57,
       57,   57,   57,   51,   59,   58,   57,   57,   57,   57,

       57,   79,  102,   68,  117,   60,   77,   61,   70,   62,
       64,   63,   65,   80,   57,   66,   69,   71,   57,  115,
       57,   97,   72,   73,   67,   98,   57,  118,   57,  124,
       74,  115,   75,   81,   88,   57,   82,   83,   89,  118,
       87,   76,   90,   57,   84,   92,   57,   91,   85,   86,
       57,   57,   57,   94,   93,  121,   99,   57,   57,   57,
      110,  103,   95,   57,  111,  104,  105,   96,  108,  100,
      112,  101,   48,   49,  106,  176,   47,  107,  113,  109,
       48,   49,  128,   57,   57,   51,  116,  116,  116,  116,
      116,  116,  116,   51,  122,   57,  119,   51,  120,  120,

      120,  120,  120,  120,  120,   51,   57,   57,   57,  123,
       57,  130,   57,   57,   57,  126,   57,   57,   57,   57,
       57,   57,   57,   57,  138,  143,  125,  129,  134,  127,
      132,  141,  148,  131,  133,  140,  135,  136,  139,  137,
       57,  144,  142,   57,   57,  147,  145,   57,   57,   57,
       57,   57,   57,   57,  150,  151,   57,  155,  153,  154,
      149,   57,   57,   57,   57,  163,   57,  165,  164,  156,
      152,  158,  159,   57,  157,   57,  168,   57,   57,  160,
      167,   57,  169,  161,  162,   57,  166,  172,   57,   57,
       57,  171,  177,  174,   57,   57,   57,  170,  173,   57,

       57,  184,  181,  179,   57,   57,  195,  180,  175,  178,
      182,  208,  183,  188,  186,   48,   49,  185,  187,  189,
      191,  190,  190,  190,  190,  190,  190,  190,   51,  385,
       57,  192,  191,  193,  193,  193,  193,  193,  193,  193,
       51,  120,  120,  120,  120,  120,  120,  120,  120,  120,
      120,  120,  120,  120,  120,   57,   57,   57,  194,   57,
       57,   57,   57,   57,   57,  201,  196,  199,   57,  198,
       57,  197,  200,  202,  203,   57,   57,   57,  205,   57,
       57,   57,   57,  209,   57,   57,   57,  215,  204,   57,
      212,  216,  206,  219,  214,  218,  217,  210,   57,  221,

      213,   57,  211,  207,  223,   57,  224,  226,  225,  220,
       57,   57,   57,  227,   57,   57,   57,  222,   57,   57,
      228,   57,   57,  229,   57,   57,  231,  235,  233,   57,
      232,   57,  240,   57,   57,  230,  236,  238,   57,   57,
      239,  234,   57,   57,   57,  237,   57,  241,  246,   57,
      249,   57,  244,   57,  242,   57,   57,  243,   57,   57,
      245,   57,  247,  252,   57,   57,   57,  248,   57,  250,
      256,   57,   57,  251,  632,   57,  254,  255,  253,  259,
      258,   57,  261,  288,  257,  273,  260,  190,  190,  190,
      190,  190,  190,  190,  262,  190,  190,  190,  190,  190,

      190,  190,  263,  266,  264,  264,  264,  264,  264,  264,
      264,  193,  193,  193,  193,  193,  193,  193,  193,  193,
      193,  193,  193,  193,  193,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,  270,  275,   57,   57,  631,
      268,   57,   57,  267,   57,   57,  272,   57,  269,  280,
      277,  278,  271,   57,  274,  286,  294,  276,   57,  279,
       57,   57,  285,  287,  281,  289,  293,   57,   57,  295,
       57,  297,   57,   57,   57,   57,   57,   57,  300,   57,
       57,  296,   57,  304,  301,  298,  302,   57,   57,  305,
       57,  299,  310,  303,   57,   57,   57,   57,   57,  307,

      306,   57,   57,   57,   57,  308,  314,   57,  312,  316,
      309,   57,   57,  313,   57,  311,  315,  324,  317,  318,
      320,   57,  321,  319,  322,  323,  325,   57,   57,  346,
      328,  326,   57,  630,  388,  330,   57,  327,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,   57,   57,   57,   57,  334,   57,   57,   57,
      332,  329,   57,  331,  335,  333,   57,   57,   57,   57,
       57,   57,  339,   57,   57,  338,  337,   57,   57,  336,
      350,   57,  342,   57,   57,  340,   57,  347,   57,  348,
      341,  356,  359,  349,   57,  360,  354,  357,   57,   57,

      629,  358,   57,   57,   57,   57,   57,   57,  364,   57,
      362,   57,   57,  367,  361,   57,  366,  371,  363,  369,
      368,  374,  365,  370,  376,  372,   57,  375,  373,   57,
       57,   57,  377,   57,   57,   57,   57,  383,  386,   57,
      379,   57,  387,  378,   57,   57,   57,  391,   57,   57,
      394,  384,   57,   57,   57,   57,   57,  390,  400,  389,
      392,   57,   57,  402,   57,   57,  395,  393,  409,   57,
       57,  410,  396,  401,  406,   57,   57,   57,   57,  414,
       57,   57,   57,   57,  408,  413,  421,  411,   57,   57,
       57,   57,  420,  412,   57,  417,  418,   57,  419,  423,

      415,  416,   57,   57,  429,   57,  422,  432,  430,  424,
       57,   57,  428,  431,  433,   57,   57,   57,   57,  435,
      437,   57,   57,  442,   57,  434,   57,   57,   57,   57,
       57,   57,   57,   57,  436,  455,  450,  451,  441,  446,
      452,  448,   57,  458,  449,  454,  453,   57,  456,   57,
      459,   57,   57,  457,   57,   57,  463,   57,   57,   57,
      466,  465,   57,  464,   57,   57,   57,   57,   57,   57,
       57,   57,  467,  468,  479,  480,  485,   57,   57,   57,
      470,  487,  474,   57,  481,  469,   57,   57,   57,  484,
      482,   57,   57,   57,  488,   57,  483,  506,  486,  496,

      492,   57,  493,   57,   57,  494,  505,   57,  497,  507,
      495,   57,   57,  514,   57,  508,   57,   57,  515,  509,
       57,  516,  517,   57,   57,  513,  526,   57,   57,   57,
      527,   57,  535,  534,  525,  528,   57,  532,  533,   57,
      543,   57,   57,   57,   57,  542,   57,  544,   57,   57,
       57,   57,   57,  558,  560,   57,  550,  548,  551,   57,
      559,  564,  567,   57,  549,  565,  566,   57,   57,  575,
      574,   57,   57,   57,  579,   57,  628,  580,  627,  626,
      587,  593,  625,  624,  623,  603,  622,  588,  592,   50,
       50,   57,   57,   46,   46,   56,   56,  116,  116,  621,

      620,  619,  618,  617,  616,  615,  614,  613,   57,  612,
      611,  610,  609,  608,  607,  606,  605,  604,   57,  602,
      601,  600,   57,   57,  599,  598,  597,  596,  595,  594,
      591,  590,  589,  586,  585,  584,  583,  582,  581,   57,
       57,  578,  577,  576,   57,  573,  572,  571,  570,  569,
      568,  563,  562,  561,  557,  556,  555,  554,  553,  552,
      547,  546,  545,   57,  541,  540,  539,  538,  537,  536,
       57,  531,  530,  529,   57,  524,  523,  522,  521,  520,
      519,  518,   57,  512,  511,  510,   57,   57,   57,   57,
       57,  504,  503,  502,  501,   57,  500,  499,  498,   57,

       57,  491,  490,  489,   57,   57,  478,   57,  477,  476,
      475,   57,  473,  472,  471,   57,   57,  462,  461,  460,
       57,   57,   57,   57,   57,  447,  445,  444,  443,   57,
      440,  439,  438,   57,   57,   57,   57,  427,  426,  425,
       57,   57,   57,   57,   57,   57,   57,  407,  405,  404,
      403,   57,   57,  399,  398,  397,   57,   57,   57,   57,
       57,  382,  381,  380,   57,   57,  355,  353,  352,  351,
      345,  344,  343,   57,   57,   57,   57,   57,   57,   57,
       57,  292,  291,  290,  284,  283,  282,   57,   57,   57,
       57,   57,  265,   57,   57,   57,   57,   57,   57,   57,

       57,  146,   57,   43,  114,   55,   54,   45,   44,   43,
      633,    3,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633
    } ;

static grib_yyconst flex_int16_t grib_yy_chk[1267] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,   11,   11,   11,   11,   11,   11,
       11,   12,   12,   12,   12,   12,   12,   12,   13,   13,
       14,   14,   17,   17,   17,   17,   17,   17,   17,   27,
       19,   13,   18,   18,   18,   18,   18,   18,   18,   21,
       26,   27,   36,   13,   19,   18,   22,   23,   24,   28,

       34,   27,   36,   23,  638,   21,   26,   21,   24,   21,
       22,   21,   22,   28,   25,   22,   23,   24,   30,   47,
       61,   34,   24,   25,   22,   34,   29,   49,   31,   61,
       25,   47,   25,   29,   31,   32,   29,   29,   31,   49,
       30,   25,   31,   33,   29,   32,   39,   31,   29,   29,
       35,   37,   58,   33,   32,   58,   35,   40,   38,   64,
       39,   37,   33,  104,   39,   37,   37,   33,   38,   35,
       40,   35,   46,   46,   37,  104,  637,   37,   40,   38,
       50,   50,   64,   59,   66,   46,   48,   48,   48,   48,
       48,   48,   48,   50,   59,   60,   51,   46,   51,   51,

       51,   51,   51,   51,   51,   50,   62,   63,   65,   60,
       67,   66,   68,   70,   71,   63,   75,   73,   72,   69,
       74,   76,   79,   80,   70,   75,   62,   65,   69,   63,
       68,   73,   80,   67,   68,   72,   69,   69,   71,   69,
       77,   76,   74,   81,   82,   79,   77,   84,   86,   87,
       88,   89,   90,   91,   82,   84,   93,   88,   86,   87,
       81,   92,   94,   95,   96,   93,   98,   95,   94,   89,
       84,   91,   91,   99,   90,  100,   98,  101,  105,   91,
       96,  102,   99,   92,   92,  103,   95,  102,  106,  107,
      108,  101,  105,  103,  110,  111,  109,  100,  102,  113,

      123,  111,  109,  107,  112,  138,  123,  108,  103,  106,
      109,  138,  110,  113,  112,  116,  116,  111,  112,  115,
      117,  115,  115,  115,  115,  115,  115,  115,  116,  328,
      328,  118,  117,  118,  118,  118,  118,  118,  118,  118,
      116,  119,  119,  119,  119,  119,  119,  119,  120,  120,
      120,  120,  120,  120,  120,  121,  125,  126,  121,  127,
      129,  132,  131,  133,  134,  132,  125,  129,  135,  127,
      136,  126,  131,  133,  134,  137,  139,  140,  136,  141,
      142,  144,  145,  139,  148,  147,  153,  146,  135,  150,
      142,  146,  136,  148,  145,  147,  146,  140,  149,  150,

      144,  151,  141,  137,  152,  154,  152,  153,  152,  149,
      155,  156,  157,  154,  158,  159,  152,  151,  160,  161,
      155,  162,  163,  156,  164,  166,  158,  162,  160,  165,
      159,  167,  166,  168,  169,  157,  163,  165,  170,  172,
      165,  161,  171,  173,  174,  164,  175,  167,  172,  178,
      175,  176,  170,  177,  168,  179,  180,  169,  182,  181,
      171,  183,  173,  178,  184,  185,  187,  174,  186,  176,
      182,  188,  221,  177,  628,  205,  180,  181,  179,  185,
      184,  195,  187,  221,  183,  205,  186,  189,  189,  189,
      189,  189,  189,  189,  188,  190,  190,  190,  190,  190,

      190,  190,  191,  195,  191,  191,  191,  191,  191,  191,
      191,  192,  192,  192,  192,  192,  192,  192,  193,  193,
      193,  193,  193,  193,  193,  196,  197,  198,  201,  203,
      204,  206,  207,  208,  209,  201,  207,  211,  213,  627,
      197,  222,  214,  196,  218,  219,  204,  220,  198,  214,
      209,  211,  203,  228,  206,  219,  227,  208,  229,  213,
      226,  232,  218,  220,  214,  222,  226,  231,  227,  228,
      233,  231,  234,  236,  238,  240,  237,  239,  234,  242,
      243,  229,  244,  239,  236,  232,  237,  245,  246,  240,
      247,  233,  246,  238,  248,  249,  250,  255,  252,  243,

      242,  253,  254,  258,  285,  244,  250,  333,  248,  253,
      245,  256,  269,  249,  259,  247,  252,  258,  254,  255,
      257,  261,  257,  256,  257,  257,  259,  262,  265,  285,
      265,  261,  257,  626,  333,  269,  273,  262,  263,  263,
      263,  263,  263,  263,  263,  264,  264,  264,  264,  264,
      264,  264,  267,  270,  271,  272,  273,  275,  274,  276,
      271,  267,  277,  270,  274,  272,  278,  279,  280,  286,
      287,  289,  277,  293,  297,  276,  275,  288,  296,  274,
      289,  298,  280,  300,  299,  278,  301,  286,  302,  287,
      279,  296,  299,  288,  304,  300,  293,  297,  303,  305,

      625,  298,  306,  307,  310,  308,  312,  311,  304,  313,
      302,  316,  314,  307,  301,  315,  306,  311,  303,  308,
      307,  314,  305,  310,  316,  312,  317,  315,  313,  318,
      319,  324,  317,  325,  331,  332,  334,  324,  331,  335,
      319,  336,  332,  318,  338,  337,  339,  336,  340,  342,
      339,  325,  348,  350,  349,  354,  357,  335,  348,  334,
      337,  360,  359,  350,  362,  363,  340,  338,  359,  364,
      366,  360,  342,  349,  354,  367,  369,  368,  370,  366,
      372,  373,  375,  377,  357,  364,  375,  362,  379,  378,
      383,  386,  373,  363,  384,  369,  370,  387,  372,  378,

      367,  368,  390,  388,  384,  391,  377,  388,  386,  379,
      389,  394,  383,  387,  389,  400,  395,  401,  406,  391,
      395,  408,  409,  401,  416,  390,  414,  415,  417,  418,
      421,  419,  423,  422,  394,  419,  414,  415,  400,  406,
      416,  408,  420,  422,  409,  418,  417,  429,  420,  430,
      423,  431,  432,  421,  433,  435,  429,  436,  437,  442,
      432,  431,  456,  430,  448,  449,  451,  452,  454,  455,
      457,  459,  433,  435,  448,  449,  456,  458,  464,  469,
      437,  458,  442,  466,  451,  436,  467,  468,  470,  455,
      452,  484,  482,  485,  459,  486,  454,  484,  457,  469,

      464,  487,  466,  492,  493,  467,  482,  494,  470,  485,
      468,  496,  497,  493,  505,  486,  509,  506,  494,  487,
      508,  496,  497,  513,  517,  492,  506,  515,  514,  525,
      508,  526,  517,  515,  505,  509,  528,  513,  514,  532,
      526,  533,  534,  542,  535,  525,  543,  528,  544,  548,
      550,  551,  559,  542,  544,  560,  534,  532,  535,  549,
      543,  548,  551,  567,  533,  549,  550,  565,  574,  560,
      559,  575,  579,  580,  565,  592,  621,  567,  620,  619,
      574,  580,  618,  617,  616,  592,  615,  575,  579,  634,
      634,  635,  635,  636,  636,  639,  639,  640,  640,  613,

      612,  611,  610,  609,  608,  607,  606,  604,  603,  602,
      601,  600,  599,  598,  597,  596,  595,  594,  593,  591,
      590,  589,  588,  587,  586,  585,  584,  583,  582,  581,
      578,  577,  576,  573,  572,  571,  570,  569,  568,  566,
      564,  563,  562,  561,  558,  557,  556,  555,  554,  553,
      552,  547,  546,  545,  541,  540,  539,  538,  537,  536,
      531,  530,  529,  527,  523,  522,  521,  520,  519,  518,
      516,  512,  511,  510,  507,  504,  503,  502,  501,  500,
      499,  498,  495,  491,  490,  489,  488,  483,  481,  480,
      479,  478,  477,  476,  475,  474,  473,  472,  471,  465,

      463,  462,  461,  460,  453,  450,  447,  446,  445,  444,
      443,  441,  440,  439,  438,  434,  428,  427,  426,  425,
      424,  413,  412,  411,  410,  407,  405,  404,  403,  402,
      399,  398,  397,  396,  393,  392,  385,  382,  381,  380,
      376,  374,  371,  365,  361,  358,  356,  355,  353,  352,
      351,  347,  346,  345,  344,  343,  341,  330,  329,  327,
      326,  322,  321,  320,  309,  295,  294,  292,  291,  290,
      284,  283,  282,  281,  268,  266,  260,  251,  241,  235,
      230,  225,  224,  223,  217,  216,  215,  212,  210,  202,
      200,  199,  194,  143,  130,  128,  124,  122,   97,   85,

       83,   78,   57,   43,   41,   16,   15,   10,    7,    5,
        3,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  633
    } ;

static grib_yy_state_type grib_yy_last_accepting_state;
static char *grib_yy_last_accepting_cpos;

extern int grib_yy_flex_debug;
int grib_yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define grib_yymore() grib_yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *grib_yytext;
#line 1 "gribl.l"
/*
 * Copyright 2005-2016 ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
 * virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 */
#line 13 "gribl.l"
#include "grib_api_internal.h"
#include "grib_yacc.h"
#include <ctype.h>

extern int grib_yylineno;

/* Keep -Wall quiet */


/*

This is needed for implementing "include", otherwise
flex buffer optimization break the includes.

*/

#define YY_INPUT(buf,result,max_size) \
        { \
        int c = getc(grib_yyin); \
        result = (c == EOF) ? YY_NULL : (buf[0] = c, 1); \
        }


/*
#ifdef __GNUC__
#ifdef FLEX_SCANNER
void grib_yyunput (int c,char *buf_ptr  );
void _grib_ignore_grib_yyunput_unused_error() { grib_yyunput(0,0); }
#endif
#endif
*/

#ifdef __cplusplus
 #define GET_INPUT grib_yyinput
#else
 #define GET_INPUT input
#endif

#line 985 "lex.grib_yy.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int grib_yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int grib_yylex_destroy (void );

int grib_yyget_debug (void );

void grib_yyset_debug (int debug_flag  );

YY_EXTRA_TYPE grib_yyget_extra (void );

void grib_yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *grib_yyget_in (void );

void grib_yyset_in  (FILE * in_str  );

FILE *grib_yyget_out (void );

void grib_yyset_out  (FILE * out_str  );

int grib_yyget_leng (void );

char *grib_yyget_text (void );

int grib_yyget_lineno (void );

void grib_yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int grib_yywrap (void );
#else
extern int grib_yywrap (void );
#endif
#endif

    void grib_yyunput (int c,char *buf_ptr  );
    
#ifndef grib_yytext_ptr
static void grib_yy_flex_strncpy (char *,grib_yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int grib_yy_flex_strlen (grib_yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int grib_yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( grib_yytext, grib_yyleng, 1, grib_yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->grib_yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( grib_yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( grib_yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, grib_yyin))==0 && ferror(grib_yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(grib_yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "grib_yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef grib_yyterminate
#define grib_yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) grib_yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int grib_yylex (void);

#define YY_DECL int grib_yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after grib_yytext and grib_yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register grib_yy_state_type grib_yy_current_state;
	register char *grib_yy_cp, *grib_yy_bp;
	register int grib_yy_act;
    
#line 65 "gribl.l"



#line 1171 "lex.grib_yy.c"

	if ( !(grib_yy_init) )
		{
		(grib_yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (grib_yy_start) )
			(grib_yy_start) = 1;	/* first start state */

		if ( ! grib_yyin )
			grib_yyin = stdin;

		if ( ! grib_yyout )
			grib_yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			grib_yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				grib_yy_create_buffer(grib_yyin,YY_BUF_SIZE );
		}

		grib_yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		grib_yy_cp = (grib_yy_c_buf_p);

		/* Support of grib_yytext. */
		*grib_yy_cp = (grib_yy_hold_char);

		/* grib_yy_bp points to the position in grib_yy_ch_buf of the start of
		 * the current run.
		 */
		grib_yy_bp = grib_yy_cp;

		grib_yy_current_state = (grib_yy_start);
grib_yy_match:
		do
			{
			register YY_CHAR grib_yy_c = grib_yy_ec[YY_SC_TO_UI(*grib_yy_cp)];
			if ( grib_yy_accept[grib_yy_current_state] )
				{
				(grib_yy_last_accepting_state) = grib_yy_current_state;
				(grib_yy_last_accepting_cpos) = grib_yy_cp;
				}
			while ( grib_yy_chk[grib_yy_base[grib_yy_current_state] + grib_yy_c] != grib_yy_current_state )
				{
				grib_yy_current_state = (int) grib_yy_def[grib_yy_current_state];
				if ( grib_yy_current_state >= 634 )
					grib_yy_c = grib_yy_meta[(unsigned int) grib_yy_c];
				}
			grib_yy_current_state = grib_yy_nxt[grib_yy_base[grib_yy_current_state] + (unsigned int) grib_yy_c];
			++grib_yy_cp;
			}
		while ( grib_yy_base[grib_yy_current_state] != 1212 );

grib_yy_find_action:
		grib_yy_act = grib_yy_accept[grib_yy_current_state];
		if ( grib_yy_act == 0 )
			{ /* have to back up */
			grib_yy_cp = (grib_yy_last_accepting_cpos);
			grib_yy_current_state = (grib_yy_last_accepting_state);
			grib_yy_act = grib_yy_accept[grib_yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( grib_yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*grib_yy_cp = (grib_yy_hold_char);
			grib_yy_cp = (grib_yy_last_accepting_cpos);
			grib_yy_current_state = (grib_yy_last_accepting_state);
			goto grib_yy_find_action;

case 1:
YY_RULE_SETUP
#line 68 "gribl.l"
return EQ       ;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 69 "gribl.l"
return GE       ;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 70 "gribl.l"
return GT       ;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 71 "gribl.l"
return LE       ;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 72 "gribl.l"
return LT       ;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 73 "gribl.l"
return NE       ;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 74 "gribl.l"
return NE       ;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 75 "gribl.l"
return BIT      ;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 76 "gribl.l"
return BITOFF   ;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 78 "gribl.l"
return IS   ;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 79 "gribl.l"
return NOT   ;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 80 "gribl.l"
return NOT   ;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 81 "gribl.l"
return AND   ;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 82 "gribl.l"
return AND   ;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 83 "gribl.l"
return OR   ;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 84 "gribl.l"
return OR   ;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 86 "gribl.l"
return NIL   ;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 87 "gribl.l"
return DUMMY   ;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 89 "gribl.l"
return LOWERCASE;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 90 "gribl.l"
return IF       ;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 91 "gribl.l"
return IF_TRANSIENT       ;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 92 "gribl.l"
return ELSE       ;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 93 "gribl.l"
return UNSIGNED ;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 94 "gribl.l"
return ASCII    ;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 95 "gribl.l"
return BYTE    ;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 96 "gribl.l"
return LABEL    ;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 97 "gribl.l"
return LIST     ;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 98 "gribl.l"
return WHILE     ;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 99 "gribl.l"
return TEMPLATE ;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 100 "gribl.l"
return TEMPLATE_NOFAIL ;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 101 "gribl.l"
return TRIGGER ;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 102 "gribl.l"
return END      ;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 103 "gribl.l"
return IBMFLOAT ;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 104 "gribl.l"
return FLOAT ;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 105 "gribl.l"
return SIGNED   ;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 106 "gribl.l"
return CODETABLE;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 107 "gribl.l"
return GETENV;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 108 "gribl.l"
return CODETABLE;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 109 "gribl.l"
return FLAG     ;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 110 "gribl.l"
return LOOKUP   ;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 111 "gribl.l"
return META     ;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 112 "gribl.l"
return PADTOEVEN    ;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 113 "gribl.l"
return PADTO    ;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 114 "gribl.l"
return PADTOMULTIPLE    ;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 115 "gribl.l"
return PAD      ;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 116 "gribl.l"
return SECTION_PADDING      ;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 117 "gribl.l"
return MESSAGE      ;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 118 "gribl.l"
return ALIAS    ;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 119 "gribl.l"
return UNALIAS    ;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 120 "gribl.l"
return POS      ;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 121 "gribl.l"
return INTCONST ;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 122 "gribl.l"
return TRANS    ;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 123 "gribl.l"
return STRING_TYPE   ;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 124 "gribl.l"
return LONG_TYPE   ;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 125 "gribl.l"
return DOUBLE_TYPE   ;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 126 "gribl.l"
return ITERATOR ;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 127 "gribl.l"
return NEAREST ;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 128 "gribl.l"
return BOX ;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 129 "gribl.l"
return KSEC    ;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 130 "gribl.l"
return FLAGBIT    ;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 131 "gribl.l"
return KSEC1EXPVER    ;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 132 "gribl.l"
return MODIFY    ;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 134 "gribl.l"
return G1_HALF_BYTE    ;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 135 "gribl.l"
return G1_MESSAGE_LENGTH    ;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 136 "gribl.l"
return G1_SECTION4_LENGTH    ;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 138 "gribl.l"
return EXPORT;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 139 "gribl.l"
return REMOVE;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 141 "gribl.l"
return SECTION_LENGTH     ;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 143 "gribl.l"
return ASSERT    ;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 145 "gribl.l"
return READ_ONLY;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 146 "gribl.l"
return NO_COPY;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 147 "gribl.l"
return EDITION_SPECIFIC;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 148 "gribl.l"
return DUMP;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 149 "gribl.l"
return NO_FAIL;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 150 "gribl.l"
return HIDDEN;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 151 "gribl.l"
return CAN_BE_MISSING;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 152 "gribl.l"
return MISSING;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 153 "gribl.l"
return CONSTRAINT;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 154 "gribl.l"
return OVERRIDE;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 155 "gribl.l"
return COPY_OK;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 157 "gribl.l"
return UINT8;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 158 "gribl.l"
return INT8;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 160 "gribl.l"
return UINT16;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 161 "gribl.l"
return INT16;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 162 "gribl.l"
return UINT16_LITTLE_ENDIAN;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 163 "gribl.l"
return INT16_LITTLE_ENDIAN;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 165 "gribl.l"
return UINT32;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 166 "gribl.l"
return INT32;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 167 "gribl.l"
return UINT32_LITTLE_ENDIAN;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 168 "gribl.l"
return INT32_LITTLE_ENDIAN;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 170 "gribl.l"
return UINT64;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 171 "gribl.l"
return INT64;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 172 "gribl.l"
return UINT64_LITTLE_ENDIAN;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 173 "gribl.l"
return INT64_LITTLE_ENDIAN;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 175 "gribl.l"
return BLOB;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 177 "gribl.l"
return SET;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 178 "gribl.l"
return SET_NOFAIL;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 179 "gribl.l"
return WHEN;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 180 "gribl.l"
return CASE;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 181 "gribl.l"
return SWITCH;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 182 "gribl.l"
return DEFAULT;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 183 "gribl.l"
return CONCEPT;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 184 "gribl.l"
return CONCEPT_NOFAIL;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 185 "gribl.l"
return WRITE;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 186 "gribl.l"
return APPEND;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 187 "gribl.l"
return PRINT;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 188 "gribl.l"
return SKIP;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 190 "gribl.l"
{
          int c,q;
          while((c = GET_INPUT()) && isspace(c) && c != '\n') ;
          q = c; /* the quote */

          grib_yyleng = 0;
          while((c = GET_INPUT()) && c != q && c != '\n')
                {
                    if(c == '\\') grib_yytext[grib_yyleng++] = GET_INPUT();
                    else grib_yytext[grib_yyleng++] =  c;
                }

                grib_yytext[grib_yyleng++] = 0;

          grib_parser_include(grib_yytext);
         }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 207 "gribl.l"
{
           int c,q = grib_yytext[0];

           grib_yyleng = 0;

           while((c = GET_INPUT()) && c != q && c != '\n')
           {
               if(c == '\\') grib_yytext[grib_yyleng++] = GET_INPUT();
               else grib_yytext[grib_yyleng++] =  c;
            }

            grib_yytext[grib_yyleng++] = 0;
            grib_yylval.str = strdup(grib_yytext);
            return STRING;
        }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 223 "gribl.l"
{
           int c;
           unsigned long val = 0;

           while((c = GET_INPUT()) && c != '`' && c != '\n')
           {
                val <<= 8;
                val |= c;
           }
           grib_yylval.lval = val;
           return INTEGER;
        }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 237 "gribl.l"
{ grib_yylval.str = strdup(grib_yytext); return IDENT; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 238 "gribl.l"
{ grib_yylval.lval = atol((const char *)grib_yytext); return INTEGER; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 239 "gribl.l"
{ grib_yylval.lval = atol((const char *)grib_yytext); return INTEGER; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 240 "gribl.l"
{ grib_yylval.dval = atof((const char *)grib_yytext); return FLOAT; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 241 "gribl.l"
{ grib_yylval.dval = atof((const char *)grib_yytext); return FLOAT; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 242 "gribl.l"
{ grib_yylval.dval = atof((const char *)grib_yytext); return FLOAT; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 245 "gribl.l"
{
           int c;
           while((c = GET_INPUT()) && (c != '\n')){}

        grib_yylineno++;
        }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 251 "gribl.l"
;
	YY_BREAK
case 119:
/* rule 119 can match eol */
YY_RULE_SETUP
#line 252 "gribl.l"
grib_yylineno++;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 256 "gribl.l"
return *grib_yytext;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 258 "gribl.l"
ECHO;
	YY_BREAK
#line 1905 "lex.grib_yy.c"
case YY_STATE_EOF(INITIAL):
	grib_yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int grib_yy_amount_of_matched_text = (int) (grib_yy_cp - (grib_yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*grib_yy_cp = (grib_yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->grib_yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed grib_yyin at a new source and called
			 * grib_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(grib_yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->grib_yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->grib_yy_input_file = grib_yyin;
			YY_CURRENT_BUFFER_LVALUE->grib_yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for grib_yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since grib_yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (grib_yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[(grib_yy_n_chars)] )
			{ /* This was really a NUL. */
			grib_yy_state_type grib_yy_next_state;

			(grib_yy_c_buf_p) = (grib_yytext_ptr) + grib_yy_amount_of_matched_text;

			grib_yy_current_state = grib_yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * grib_yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			grib_yy_next_state = grib_yy_try_NUL_trans( grib_yy_current_state );

			grib_yy_bp = (grib_yytext_ptr) + YY_MORE_ADJ;

			if ( grib_yy_next_state )
				{
				/* Consume the NUL. */
				grib_yy_cp = ++(grib_yy_c_buf_p);
				grib_yy_current_state = grib_yy_next_state;
				goto grib_yy_match;
				}

			else
				{
				grib_yy_cp = (grib_yy_c_buf_p);
				goto grib_yy_find_action;
				}
			}

		else switch ( grib_yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(grib_yy_did_buffer_switch_on_eof) = 0;

				if ( grib_yywrap( ) )
					{
					/* Note: because we've taken care in
					 * grib_yy_get_next_buffer() to have set up
					 * grib_yytext, we can now set up
					 * grib_yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(grib_yy_c_buf_p) = (grib_yytext_ptr) + YY_MORE_ADJ;

					grib_yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (grib_yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(grib_yy_c_buf_p) =
					(grib_yytext_ptr) + grib_yy_amount_of_matched_text;

				grib_yy_current_state = grib_yy_get_previous_state(  );

				grib_yy_cp = (grib_yy_c_buf_p);
				grib_yy_bp = (grib_yytext_ptr) + YY_MORE_ADJ;
				goto grib_yy_match;

			case EOB_ACT_LAST_MATCH:
				(grib_yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[(grib_yy_n_chars)];

				grib_yy_current_state = grib_yy_get_previous_state(  );

				grib_yy_cp = (grib_yy_c_buf_p);
				grib_yy_bp = (grib_yytext_ptr) + YY_MORE_ADJ;
				goto grib_yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of grib_yylex */

/* grib_yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int grib_yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf;
	register char *source = (grib_yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (grib_yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[(grib_yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->grib_yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (grib_yy_c_buf_p) - (grib_yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((grib_yy_c_buf_p) - (grib_yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->grib_yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->grib_yy_n_chars = (grib_yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->grib_yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int grib_yy_c_buf_p_offset =
				(int) ((grib_yy_c_buf_p) - b->grib_yy_ch_buf);

			if ( b->grib_yy_is_our_buffer )
				{
				int new_size = b->grib_yy_buf_size * 2;

				if ( new_size <= 0 )
					b->grib_yy_buf_size += b->grib_yy_buf_size / 8;
				else
					b->grib_yy_buf_size *= 2;

				b->grib_yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					grib_yyrealloc((void *) b->grib_yy_ch_buf,b->grib_yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->grib_yy_ch_buf = 0;

			if ( ! b->grib_yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(grib_yy_c_buf_p) = &b->grib_yy_ch_buf[grib_yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->grib_yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[number_to_move]),
			(grib_yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->grib_yy_n_chars = (grib_yy_n_chars);
		}

	if ( (grib_yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			grib_yyrestart(grib_yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->grib_yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((grib_yy_size_t) ((grib_yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->grib_yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		grib_yy_size_t new_size = (grib_yy_n_chars) + number_to_move + ((grib_yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf = (char *) grib_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in grib_yy_get_next_buffer()" );
	}

	(grib_yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[(grib_yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[(grib_yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(grib_yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[0];

	return ret_val;
}

/* grib_yy_get_previous_state - get the state just before the EOB char was reached */

    static grib_yy_state_type grib_yy_get_previous_state (void)
{
	register grib_yy_state_type grib_yy_current_state;
	register char *grib_yy_cp;
    
	grib_yy_current_state = (grib_yy_start);

	for ( grib_yy_cp = (grib_yytext_ptr) + YY_MORE_ADJ; grib_yy_cp < (grib_yy_c_buf_p); ++grib_yy_cp )
		{
		register YY_CHAR grib_yy_c = (*grib_yy_cp ? grib_yy_ec[YY_SC_TO_UI(*grib_yy_cp)] : 1);
		if ( grib_yy_accept[grib_yy_current_state] )
			{
			(grib_yy_last_accepting_state) = grib_yy_current_state;
			(grib_yy_last_accepting_cpos) = grib_yy_cp;
			}
		while ( grib_yy_chk[grib_yy_base[grib_yy_current_state] + grib_yy_c] != grib_yy_current_state )
			{
			grib_yy_current_state = (int) grib_yy_def[grib_yy_current_state];
			if ( grib_yy_current_state >= 634 )
				grib_yy_c = grib_yy_meta[(unsigned int) grib_yy_c];
			}
		grib_yy_current_state = grib_yy_nxt[grib_yy_base[grib_yy_current_state] + (unsigned int) grib_yy_c];
		}

	return grib_yy_current_state;
}

/* grib_yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = grib_yy_try_NUL_trans( current_state );
 */
    static grib_yy_state_type grib_yy_try_NUL_trans  (grib_yy_state_type grib_yy_current_state )
{
	register int grib_yy_is_jam;
    	register char *grib_yy_cp = (grib_yy_c_buf_p);

	register YY_CHAR grib_yy_c = 1;
	if ( grib_yy_accept[grib_yy_current_state] )
		{
		(grib_yy_last_accepting_state) = grib_yy_current_state;
		(grib_yy_last_accepting_cpos) = grib_yy_cp;
		}
	while ( grib_yy_chk[grib_yy_base[grib_yy_current_state] + grib_yy_c] != grib_yy_current_state )
		{
		grib_yy_current_state = (int) grib_yy_def[grib_yy_current_state];
		if ( grib_yy_current_state >= 634 )
			grib_yy_c = grib_yy_meta[(unsigned int) grib_yy_c];
		}
	grib_yy_current_state = grib_yy_nxt[grib_yy_base[grib_yy_current_state] + (unsigned int) grib_yy_c];
	grib_yy_is_jam = (grib_yy_current_state == 633);

	return grib_yy_is_jam ? 0 : grib_yy_current_state;
}

    void grib_yyunput (int c, register char * grib_yy_bp )
{
	register char *grib_yy_cp;
    
    grib_yy_cp = (grib_yy_c_buf_p);

	/* undo effects of setting up grib_yytext */
	*grib_yy_cp = (grib_yy_hold_char);

	if ( grib_yy_cp < YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (grib_yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->grib_yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf )
			*--dest = *--source;

		grib_yy_cp += (int) (dest - source);
		grib_yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->grib_yy_n_chars =
			(grib_yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->grib_yy_buf_size;

		if ( grib_yy_cp < YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--grib_yy_cp = (char) c;

	(grib_yytext_ptr) = grib_yy_bp;
	(grib_yy_hold_char) = *grib_yy_cp;
	(grib_yy_c_buf_p) = grib_yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int grib_yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(grib_yy_c_buf_p) = (grib_yy_hold_char);

	if ( *(grib_yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* grib_yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (grib_yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->grib_yy_ch_buf[(grib_yy_n_chars)] )
			/* This was really a NUL. */
			*(grib_yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (grib_yy_c_buf_p) - (grib_yytext_ptr);
			++(grib_yy_c_buf_p);

			switch ( grib_yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because grib_yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					grib_yyrestart(grib_yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( grib_yywrap( ) )
						return EOF;

					if ( ! (grib_yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return grib_yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(grib_yy_c_buf_p) = (grib_yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (grib_yy_c_buf_p);	/* cast for 8-bit char's */
	*(grib_yy_c_buf_p) = '\0';	/* preserve grib_yytext */
	(grib_yy_hold_char) = *++(grib_yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void grib_yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        grib_yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            grib_yy_create_buffer(grib_yyin,YY_BUF_SIZE );
	}

	grib_yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	grib_yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void grib_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		grib_yypop_buffer_state();
	 *		grib_yypush_buffer_state(new_buffer);
     */
	grib_yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grib_yy_c_buf_p) = (grib_yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->grib_yy_buf_pos = (grib_yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grib_yy_n_chars = (grib_yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	grib_yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (grib_yywrap()) processing, but the only time this flag
	 * is looked at is after grib_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(grib_yy_did_buffer_switch_on_eof) = 1;
}

static void grib_yy_load_buffer_state  (void)
{
    	(grib_yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->grib_yy_n_chars;
	(grib_yytext_ptr) = (grib_yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->grib_yy_buf_pos;
	grib_yyin = YY_CURRENT_BUFFER_LVALUE->grib_yy_input_file;
	(grib_yy_hold_char) = *(grib_yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE grib_yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) grib_yyalloc(sizeof( struct grib_yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grib_yy_create_buffer()" );

	b->grib_yy_buf_size = size;

	/* grib_yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->grib_yy_ch_buf = (char *) grib_yyalloc(b->grib_yy_buf_size + 2  );
	if ( ! b->grib_yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in grib_yy_create_buffer()" );

	b->grib_yy_is_our_buffer = 1;

	grib_yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with grib_yy_create_buffer()
 * 
 */
    void grib_yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->grib_yy_is_our_buffer )
		grib_yyfree((void *) b->grib_yy_ch_buf  );

	grib_yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a grib_yyrestart() or at EOF.
 */
    static void grib_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	grib_yy_flush_buffer(b );

	b->grib_yy_input_file = file;
	b->grib_yy_fill_buffer = 1;

    /* If b is the current buffer, then grib_yy_init_buffer was _probably_
     * called from grib_yyrestart() or through grib_yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->grib_yy_bs_lineno = 1;
        b->grib_yy_bs_column = 0;
    }

        b->grib_yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void grib_yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->grib_yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->grib_yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->grib_yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->grib_yy_buf_pos = &b->grib_yy_ch_buf[0];

	b->grib_yy_at_bol = 1;
	b->grib_yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		grib_yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void grib_yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	grib_yyensure_buffer_stack();

	/* This block is copied from grib_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grib_yy_c_buf_p) = (grib_yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->grib_yy_buf_pos = (grib_yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grib_yy_n_chars = (grib_yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(grib_yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from grib_yy_switch_to_buffer. */
	grib_yy_load_buffer_state( );
	(grib_yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void grib_yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	grib_yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((grib_yy_buffer_stack_top) > 0)
		--(grib_yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		grib_yy_load_buffer_state( );
		(grib_yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void grib_yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(grib_yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(grib_yy_buffer_stack) = (struct grib_yy_buffer_state**)grib_yyalloc
								(num_to_alloc * sizeof(struct grib_yy_buffer_state*)
								);
		if ( ! (grib_yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grib_yyensure_buffer_stack()" );
								  
		memset((grib_yy_buffer_stack), 0, num_to_alloc * sizeof(struct grib_yy_buffer_state*));
				
		(grib_yy_buffer_stack_max) = num_to_alloc;
		(grib_yy_buffer_stack_top) = 0;
		return;
	}

	if ((grib_yy_buffer_stack_top) >= ((grib_yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (grib_yy_buffer_stack_max) + grow_size;
		(grib_yy_buffer_stack) = (struct grib_yy_buffer_state**)grib_yyrealloc
								((grib_yy_buffer_stack),
								num_to_alloc * sizeof(struct grib_yy_buffer_state*)
								);
		if ( ! (grib_yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grib_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((grib_yy_buffer_stack) + (grib_yy_buffer_stack_max), 0, grow_size * sizeof(struct grib_yy_buffer_state*));
		(grib_yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE grib_yy_scan_buffer  (char * base, grib_yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) grib_yyalloc(sizeof( struct grib_yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grib_yy_scan_buffer()" );

	b->grib_yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->grib_yy_buf_pos = b->grib_yy_ch_buf = base;
	b->grib_yy_is_our_buffer = 0;
	b->grib_yy_input_file = 0;
	b->grib_yy_n_chars = b->grib_yy_buf_size;
	b->grib_yy_is_interactive = 0;
	b->grib_yy_at_bol = 1;
	b->grib_yy_fill_buffer = 0;
	b->grib_yy_buffer_status = YY_BUFFER_NEW;

	grib_yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to grib_yylex() will
 * scan from a @e copy of @a str.
 * @param grib_yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       grib_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE grib_yy_scan_string (grib_yyconst char * grib_yystr )
{
    
	return grib_yy_scan_bytes(grib_yystr,strlen(grib_yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to grib_yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE grib_yy_scan_bytes  (grib_yyconst char * grib_yybytes, int  _grib_yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	grib_yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _grib_yybytes_len + 2;
	buf = (char *) grib_yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in grib_yy_scan_bytes()" );

	for ( i = 0; i < _grib_yybytes_len; ++i )
		buf[i] = grib_yybytes[i];

	buf[_grib_yybytes_len] = buf[_grib_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = grib_yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in grib_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->grib_yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void grib_yy_fatal_error (grib_yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine grib_yyless() so it works in section 3 code. */

#undef grib_yyless
#define grib_yyless(n) \
	do \
		{ \
		/* Undo effects of setting up grib_yytext. */ \
        int grib_yyless_macro_arg = (n); \
        YY_LESS_LINENO(grib_yyless_macro_arg);\
		grib_yytext[grib_yyleng] = (grib_yy_hold_char); \
		(grib_yy_c_buf_p) = grib_yytext + grib_yyless_macro_arg; \
		(grib_yy_hold_char) = *(grib_yy_c_buf_p); \
		*(grib_yy_c_buf_p) = '\0'; \
		grib_yyleng = grib_yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int grib_yyget_lineno  (void)
{
        
    return grib_yylineno;
}

/** Get the input stream.
 * 
 */
FILE *grib_yyget_in  (void)
{
        return grib_yyin;
}

/** Get the output stream.
 * 
 */
FILE *grib_yyget_out  (void)
{
        return grib_yyout;
}

/** Get the length of the current token.
 * 
 */
int grib_yyget_leng  (void)
{
        return grib_yyleng;
}

/** Get the current token.
 * 
 */

char *grib_yyget_text  (void)
{
        return grib_yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void grib_yyset_lineno (int  line_number )
{
    
    grib_yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see grib_yy_switch_to_buffer
 */
void grib_yyset_in (FILE *  in_str )
{
        grib_yyin = in_str ;
}

void grib_yyset_out (FILE *  out_str )
{
        grib_yyout = out_str ;
}

int grib_yyget_debug  (void)
{
        return grib_yy_flex_debug;
}

void grib_yyset_debug (int  bdebug )
{
        grib_yy_flex_debug = bdebug ;
}

static int grib_yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from grib_yylex_destroy(), so don't allocate here.
     */

    (grib_yy_buffer_stack) = 0;
    (grib_yy_buffer_stack_top) = 0;
    (grib_yy_buffer_stack_max) = 0;
    (grib_yy_c_buf_p) = (char *) 0;
    (grib_yy_init) = 0;
    (grib_yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    grib_yyin = stdin;
    grib_yyout = stdout;
#else
    grib_yyin = (FILE *) 0;
    grib_yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * grib_yylex_init()
     */
    return 0;
}

/* grib_yylex_destroy is for both reentrant and non-reentrant scanners. */
int grib_yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		grib_yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		grib_yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	grib_yyfree((grib_yy_buffer_stack) );
	(grib_yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * grib_yylex() is called, initialization will occur. */
    grib_yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef grib_yytext_ptr
static void grib_yy_flex_strncpy (char* s1, grib_yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int grib_yy_flex_strlen (grib_yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *grib_yyalloc (grib_yy_size_t  size )
{
	return (void *) malloc( size );
}

void *grib_yyrealloc  (void * ptr, grib_yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void grib_yyfree (void * ptr )
{
	free( (char *) ptr );	/* see grib_yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "grib_yytables"

#line 258 "gribl.l"




